@@ -30,6 +30,10 @@ class LPMain:
         self.beq = []
         self.senses = []
         self.inputdata = inputdata
+        self.objects_initialized = False
+
+    
+    def init_objects(self):
         self.obj_lst:list[LPObject] = [self]
         self.obj_lst.extend([value for value in vars(self).values() if isinstance(value,LPObject)])
         self.make_stateVarLst()
@@ -39,7 +43,8 @@ class LPMain:
         self.def_eqs()
         self.init_targetfun()
         self.def_targetfun()
-    
+        self.objects_initialized = True
+        
     def add_object(self,obj:LPObject):
         '''Adds an LPObject to the system'''
         self.obj_lst.append(obj)
@@ -159,6 +164,8 @@ class LPMain:
         
     def optimize(self,mipGap=0.00,solver:Solver=Solver.GUROBI,objective:Obj=Obj.MINIMIZE):
         '''Performs the linear optimization of the system of equations set up'''
+        if not self.objects_initialized:
+            self.init_objects()
         if solver == Solver.GUROBI:
             x=self.solver_gurobi(mipGap,objective)
         elif solver == Solver.SCIPY:
